@@ -6,6 +6,7 @@ Notes
 Similar to tsub_average.pro in IDL SPEDAS.
 
 """
+import logging
 import pyspedas
 import pytplot
 import numpy
@@ -39,7 +40,7 @@ def subtract_average(names, new_names=None, suffix=None, overwrite=None,
     old_names = pyspedas.tnames(names)
 
     if len(old_names) < 1:
-        print('Subtract Average error: No pytplot names were provided.')
+        logging.error('Subtract Average error: No pytplot names were provided.')
         return
 
     if suffix is None:
@@ -88,4 +89,4 @@ def subtract_average(names, new_names=None, suffix=None, overwrite=None,
 
         pytplot.data_quants[new].values = data
 
-        print('Subtract ' + ptype + ' was applied to: ' + new)
+        logging.info('Subtract ' + ptype + ' was applied to: ' + new)
